//
//  BSAltImgPreviewer.m
//  Bardiche
//
//  Created by Tsutomu Sawada on 05/12/16.
//  Copyright 2005 BathyScaphe Project. All rights reserved.
//

#import "BSAltImgPreviewer.h"
#import <SGFoundation/SGFoundation.h>
#import "NSWorkspace-BardicheEx.h"

static NSString *previewSourceHTMLFilepath(NSString *resourceName, NSString *aType)
{
	NSBundle	*bundle_;
	NSString	*path_;
	
	bundle_ = [NSBundle applicationSpecificBundle];
	path_ = [bundle_ pathForResource : resourceName ofType : aType inDirectory : PREVIEW_DIR];
	if (path_)
		return path_;

	bundle_ = [NSBundle bundleForClass : [BSAltImgPreviewer class]];
	path_ = [bundle_ pathForResource : resourceName ofType : aType inDirectory : PREVIEW_DIR];

	return path_;
}

@implementation BSAltImgPreviewer
- (id) initWithPreferences : (AppDefaults *) prefs
{
	if (self = [super init]) {
		[self setPreferences : prefs];
	}
	return self;
}

- (void) dealloc
{
	[_preferences release];
	[super dealloc];
}

- (AppDefaults *) preferences
{
	return _preferences;
}
- (void) setPreferences : (AppDefaults *) prefs
{
	id		tmp;
	
	tmp = _preferences;
	_preferences = [prefs retain];
	[tmp release];
}

- (BOOL) previewLinkWithWebBrowser : (NSURL *) aLink
{
	NSString	*path_;
	NSData		*data_;
	NSString	*src_;
	NSString	*tmpPath_;
	NSString	*dirPath_;

	path_ = previewSourceHTMLFilepath(PREVIEW_SRC, PREVIEW_TYPE);
	if (nil == path_) return NO;
	
	data_ = [NSData dataWithContentsOfFile : path_];
	src_ = [NSString stringWithData : data_ encoding : PREVIEW_ENC];
	if (nil == src_) return NO;
	
	dirPath_ = [path_ stringByDeletingLastPathComponent];
	
	// replace keyword to URL
	src_ = [src_ stringByReplaceCharacters : PREVIEW_URL_KEY
								  toString : [aLink absoluteString]];

	// replace keyword to absolute path
	src_ = [src_ stringByReplaceCharacters : PREVIEW_DIR_KEY
								  toString : dirPath_];

	// create or replace temporary file
	tmpPath_ = NSTemporaryDirectory();
	tmpPath_ = [tmpPath_ stringByAppendingPathComponent : PREVIEW_SRC];
	tmpPath_ = [tmpPath_ stringByAppendingPathExtension : PREVIEW_TYPE];
	[src_ writeToFile : tmpPath_ atomically : YES];
	
	return [[NSWorkspace sharedWorkspace] openURL : [NSURL fileURLWithPath : tmpPath_]
									 inBackGround : [[self preferences] openInBg]];
}

- (BOOL) showImageWithURL : (NSURL *) imageURL
{
	return [self previewLinkWithWebBrowser : imageURL];
}

- (BOOL) validateLink : (NSURL *) anURL
{
	return YES;
}
@end
